import time
import os.path
# from appserver import Application
from paxd.server.controller import Controller

def main():
    c = Controller('3489y3ngyqr87gy32r8fnyehwiufhe98')
    c.run()


if __name__ == '__main__':
    main()